@@ -24,6 +24,7 @@ class KNativeKafkaConsumer(threading.Thread):
         """
         self.logger = logging.getLogger()
         self.logger.info("Initializing Kafka Consumer")
+        print("Initializing Kafka Consumer")
         self.group_id = groupid
   
         
@@ -36,6 +37,8 @@ class KNativeKafkaConsumer(threading.Thread):
                     
  
         bootstrap_server=os.getenv('KAFKA_BOOTSTRAP_SERVERS',default='localhost:9092')
+        self.logger.info(bootstrap_server)
+        print(bootstrap_server)
         is_tls_enable=os.getenv('KAFKA_NET_TLS_ENABLE',default='False')
         if is_tls_enable == 'True':
             self.security_protocol="SSL"
@@ -54,21 +57,23 @@ class KNativeKafkaConsumer(threading.Thread):
             self.ssl_certfile=None
             self.ssl_keyfile=None
         self.logger.info("KafkaConsumer")
-                                                                                                                                                                                                                                                                                                                             
-        self.consumer=KafkaConsumer(
-                      bootstrap_servers=bootstrap_server,   
-                      group_id=groupid,     
-                      value_deserializer=bytes.decode,
-                      security_protocol=self.security_protocol,
-                      ssl_check_hostname=True,
-                      ssl_cafile=self.ssl_cafile,
-                      ssl_certfile=self.ssl_certfile,
-                      ssl_keyfile=self.ssl_keyfile,
-                      auto_offset_reset='earliest',
-                      enable_auto_commit=True,
-                      auto_commit_interval_ms=1000)
+        try:                                                                                                                                                                                                                                                                                                              
+            self.consumer=KafkaConsumer(
+                          bootstrap_servers=bootstrap_server,   
+                          group_id=groupid,     
+                          value_deserializer=bytes.decode,
+                          security_protocol=self.security_protocol,
+                          ssl_cafile=self.ssl_cafile,
+                          ssl_certfile=self.ssl_certfile,
+                          ssl_keyfile=self.ssl_keyfile,
+                          auto_offset_reset='earliest',
+                          enable_auto_commit=False)
+                            #auto_commit_interval_ms=1000)
+        except KafkaError as e:
+            self.logger.error(f'Kafka Error {e}')
+            raise Exception(f'Kafka Error {e}')
  
-    
+        print("KafkaConsumer Creation Success!")
     def getMessage(self) -> str:
         """
         Get the message
